'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs");
const path = require("path");
const crypto = require("crypto");
const JSONC = require('json-comments');
const tmpJsonPath = '/tmp/codeclimate-tslint';
/**
 * Normalizes tsconfg.json file.
 * Currently doing these stuffs.
 * <ul>
 *   <li>Redirect rule directories if they are not found on the original path but are defined in the tslint base path</li>
 * </ul>
 */
class ConfigFileNormalizer {
    constructor(baseOutDir) {
        this.baseOutDir = baseOutDir;
    }
    normalize(inPath, altRulesDirectory) {
        const rawConfig = JSONC.parse(fs.readFileSync(inPath).toString('UTF-8'));
        if (typeof rawConfig.rulesDirectory === 'string') {
            rawConfig.rulesDirectory = this.normalizeRulesDirectoryPath(rawConfig.rulesDirectory, altRulesDirectory);
        }
        else if (rawConfig.rulesDirectory !== undefined) {
            rawConfig.rulesDirectory = rawConfig.rulesDirectory.map(dir => this.normalizeRulesDirectoryPath(dir, altRulesDirectory));
        }
        this.ensureTemporaryDirectory();
        const outPath = this.randomFilePath();
        fs.writeFileSync(outPath, JSON.stringify(rawConfig), 'UTF-8');
        return outPath;
    }
    ensureTemporaryDirectory() {
        if (!fs.existsSync(tmpJsonPath)) {
            fs.mkdirSync(tmpJsonPath);
        }
    }
    normalizeRulesDirectoryPath(dirPath, altRulesDirectory) {
        if (!fs.existsSync(dirPath) && fs.existsSync(path.join(altRulesDirectory, dirPath))) {
            return path.join(altRulesDirectory, dirPath);
        }
        return dirPath;
    }
    randomFilePath() {
        return path.join(tmpJsonPath, `${crypto.randomBytes(32).toString('hex')}.json`);
    }
}
exports.ConfigFileNormalizer = ConfigFileNormalizer;
//# sourceMappingURL=configFileNormalizer.js.map