'use strict';
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs");
const glob = require("glob");
const _ = require("lodash");
const autobind_decorator_1 = require("autobind-decorator");
class FileMatcher {
    constructor(basePath, extensions) {
        this.basePath = basePath;
        this.extensions = extensions;
    }
    matchFiles(includePaths) {
        const expandedIncludePaths = _.flatten(includePaths.map((path) => glob.sync(`${this.basePath}${path}`)));
        const [directories, files] = _.partition(expandedIncludePaths, (file) => fs.lstatSync(file).isDirectory());
        return _.chain(directories)
            .map((directory) => glob.sync(`${directory}/**/**`))
            .flatMap(this.prunePathsWithinSymlinks)
            .concat(files)
            .filter(this.isFileWithMatchingExtension)
            .value();
    }
    prunePathsWithinSymlinks(paths) {
        const symlinks = paths.filter((path) => fs.lstatSync(path).isSymbolicLink());
        return paths.filter((path) => symlinks.every((symlink) => path.indexOf(symlink) !== 0));
    }
    isFileWithMatchingExtension(file) {
        const stats = fs.lstatSync(file);
        const extension = '.' + file.split('.').pop();
        return (stats.isFile() &&
            !stats.isSymbolicLink() &&
            this.extensions.indexOf(extension) >= 0);
    }
}
__decorate([
    autobind_decorator_1.default,
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Array]),
    __metadata("design:returntype", Array)
], FileMatcher.prototype, "matchFiles", null);
__decorate([
    autobind_decorator_1.default,
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Array]),
    __metadata("design:returntype", Array)
], FileMatcher.prototype, "prunePathsWithinSymlinks", null);
__decorate([
    autobind_decorator_1.default,
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String]),
    __metadata("design:returntype", Boolean)
], FileMatcher.prototype, "isFileWithMatchingExtension", null);
exports.FileMatcher = FileMatcher;
//# sourceMappingURL=fileMatcher.js.map