'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs");
const tsLinter_1 = require("./tsLinter");
const ruleLoader_1 = require("./ruleLoader");
const configPath = '/config.json';
const targetPath = '/code/';
const linterPath = '/usr/src/app/';
const rulesPath = '../docs/tslint-rules';
const tslintEslintRulesPath = 'node_modules/tslint-eslint-rules/dist/rules';
const codelyzerRulesPath = 'node_modules/codelyzer';
const codeClimateConfig = loadCodeClimateConfig(configPath);
const ruleLoader = new ruleLoader_1.default(linterPath);
const rules = require(rulesPath)
    .concat(ruleLoader.loadRules(tslintEslintRulesPath))
    .concat(ruleLoader.loadRules(codelyzerRulesPath));
function loadCodeClimateConfig(file) {
    if (fs.existsSync(file) && fs.statSync(file).isFile()) {
        return JSON.parse(fs.readFileSync(file).toString('utf-8'));
    }
    else {
        console.warn(`${file} does not exist, so defaulting to process all the file under the 'src' directory`);
        return { enabled: true, include_paths: ['src'] };
    }
}
const tsLinter = new tsLinter_1.TsLinter({
    targetPath,
    linterPath,
    codeClimateConfig,
    rules
});
tsLinter
    .lint()
    .map((j) => JSON.stringify(j))
    .map((json) => `${json}\u0000`)
    .subscribe((line) => console.log(line));
//# sourceMappingURL=index.js.map