'use strict';
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
const tslint_1 = require("tslint");
const _ = require("lodash");
const CodeClimate = require("./codeclimateDefinitions");
const contentRenderer_1 = require("./contentRenderer");
const autobind_decorator_1 = require("autobind-decorator");
class RuleNameNotFoundError extends Error {
    constructor(ruleName) {
        super(`rule named ${ruleName} is not found in the metadata.`);
        this.ruleName = ruleName;
    }
}
exports.RuleNameNotFoundError = RuleNameNotFoundError;
class IssueConverter {
    constructor(option) {
        this.option = option;
        this.filePattern = new RegExp(`${option.targetPath}(.*)`, 'i');
        this.contentRenderer = new contentRenderer_1.ContentRenderer(option.linterPath);
    }
    convert(failure) {
        return {
            type: CodeClimate.issueTypes.Issue,
            check_name: failure.getRuleName(),
            content: {
                body: this.contentBody(failure.getRuleName())
            },
            description: failure.getFailure(),
            categories: ['Style'],
            remediation_points: 50000,
            location: this.convertToLocation(failure)
        };
    }
    contentBody(name) {
        const rule = _.find(this.option.rules, { ruleName: name });
        if (rule != null) {
            return this.contentRenderer.render(rule);
        }
        else {
            throw new RuleNameNotFoundError(name);
        }
    }
    convertToLocation(failure) {
        return {
            path: this.getFilePath(failure),
            positions: {
                begin: this.convertToLineColumnPosition(failure.getStartPosition()),
                end: this.convertToLineColumnPosition(failure.getEndPosition())
            }
        };
    }
    getFilePath(failure) {
        return this.filePattern.exec(failure.getFileName()).pop();
    }
    convertToLineColumnPosition(position) {
        return {
            line: position.getLineAndCharacter().line + 1,
            column: position.getLineAndCharacter().character + 1
        };
    }
}
__decorate([
    autobind_decorator_1.default,
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [tslint_1.RuleFailure]),
    __metadata("design:returntype", Object)
], IssueConverter.prototype, "convert", null);
__decorate([
    autobind_decorator_1.default,
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String]),
    __metadata("design:returntype", String)
], IssueConverter.prototype, "contentBody", null);
__decorate([
    autobind_decorator_1.default,
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [tslint_1.RuleFailure]),
    __metadata("design:returntype", Object)
], IssueConverter.prototype, "convertToLocation", null);
exports.IssueConverter = IssueConverter;
//# sourceMappingURL=issueConverter.js.map