'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
const power_assert_1 = require("power-assert");
const sinon = require("sinon");
const tslint_1 = require("tslint");
const issueConverter_1 = require("../issueConverter");
const assert = require('power-assert');
describe('IssueConverter', () => {
    describe('.convert(failure: RuleFailure)', () => {
        const linterPath = './';
        const targetPath = '/base/path/';
        const codeClimateConfig = { include_paths: [] };
        const failure = 'Style failed';
        const ruleName = 'foo-rule';
        const ruleMetadata = {
            description: 'foo',
            ruleName,
            type: 'style',
            typescriptOnly: true,
            options: null,
            optionsDescription: 'option',
            optionExamples: [
                'foo', 'bar'
            ]
        };
        const converter = new issueConverter_1.IssueConverter({ targetPath, linterPath, codeClimateConfig, rules: [ruleMetadata] });
        const sourceFile = sinon.mock({});
        const sourcePath = 'path/target-source-file.ts';
        sourceFile.fileName = `${targetPath}${sourcePath}`;
        sourceFile.getLineAndCharacterOfPosition = (pos) => {
            return pos === 1 ? { line: 2, character: 30 } : { line: 8, character: 24 };
        };
        it('converts RuleFailure object properly', () => {
            // given
            const ruleFailure = new tslint_1.RuleFailure(sourceFile, 1, 2, failure, ruleName);
            // when
            const actual = converter.convert(ruleFailure);
            // then
            assert(actual !== null && actual !== undefined);
            assert(actual.type === 'issue');
            assert(actual.categories.length === 1);
            assert(actual.categories[0] === 'Style');
            assert(actual.check_name === ruleName);
            assert(actual.description === failure);
            const location = actual.location;
            const begin = location.positions.begin;
            const end = location.positions.end;
            assert(location.path === sourcePath);
            assert(begin.line === 3);
            assert(begin.column === 31);
            assert(end.line === 9);
            assert(end.column === 25);
        });
        it('throws an error when rule name is not found', () => {
            // given
            const ruleFailure = new tslint_1.RuleFailure(sourceFile, 1, 2, failure, 'non-existent');
            try {
                // when
                converter.convert(ruleFailure);
                power_assert_1.fail();
            }
            catch (e) {
                // then
                power_assert_1.ok('should fail');
            }
        });
    });
});
//# sourceMappingURL=issueConverter.spec.js.map