'use strict';
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs");
const path = require("path");
const _ = require("lodash");
const rx = require("rxjs");
const tslint_1 = require("tslint");
const fileMatcher_1 = require("./fileMatcher");
const issueConverter_1 = require("./issueConverter");
const utils_1 = require("./utils");
const autobind_decorator_1 = require("autobind-decorator");
const configFileNormalizer_1 = require("./configFileNormalizer");
class TsLinter {
    constructor(option, configFileNormalizer = new configFileNormalizer_1.ConfigFileNormalizer(option.linterPath)) {
        this.option = option;
        this.linterOption = {
            fix: false,
            formatter: 'json'
        };
        this.fileMatcher = new fileMatcher_1.FileMatcher(option.targetPath, ['.ts', '.tsx']);
        this.issueConverter = new issueConverter_1.IssueConverter(option);
        this.originalConfigPath = this.getTsLintFilePath();
        const normalizedConfigPath = configFileNormalizer.normalize(this.originalConfigPath, option.linterPath);
        this.configurationFile = tslint_1.Configuration.findConfiguration(normalizedConfigPath, '').results;
    }
    lint() {
        return rx.Observable.from(this.listFiles())
            .flatMap(this.doLint);
    }
    listFiles() {
        return this.fileMatcher.matchFiles(this.option.codeClimateConfig.include_paths);
    }
    getTsLintFilePath() {
        return _.find([
            path.join(this.option.targetPath, this.option.codeClimateConfig.config || TsLinter.defaultTsLintFileName),
            path.join(this.option.linterPath, TsLinter.defaultTsLintFileName)
        ], (file) => fs.existsSync(file));
    }
    doLint(fileName) {
        const contents = fs.readFileSync(fileName, 'utf8');
        const linter = this.createLinter();
        linter.lint(fileName, contents, this.configurationFile);
        let observable = rx.Observable.from(linter.getResult().failures);
        if (this.option.codeClimateConfig.ignore_warnings) {
            observable = observable.filter(failure => failure.getRuleSeverity() !== 'warning');
        }
        return observable
            .map(this.issueConverter.convert)
            .catch((e) => rx.Observable.of(utils_1.default.createIssueFromError(e, this.getRelativeFilePath(fileName))));
    }
    getRelativeFilePath(fileName) {
        const dirname = path.dirname(fileName);
        const basename = path.basename(fileName);
        return path.join(path.relative(this.option.targetPath, dirname), basename);
    }
    createLinter() {
        return new tslint_1.Linter(this.linterOption);
    }
}
TsLinter.defaultTsLintFileName = 'tslint.json';
__decorate([
    autobind_decorator_1.default,
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", rx.Observable)
], TsLinter.prototype, "lint", null);
__decorate([
    autobind_decorator_1.default,
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", Array)
], TsLinter.prototype, "listFiles", null);
__decorate([
    autobind_decorator_1.default,
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", String)
], TsLinter.prototype, "getTsLintFilePath", null);
__decorate([
    autobind_decorator_1.default,
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String]),
    __metadata("design:returntype", rx.Observable)
], TsLinter.prototype, "doLint", null);
__decorate([
    autobind_decorator_1.default,
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", tslint_1.Linter)
], TsLinter.prototype, "createLinter", null);
exports.TsLinter = TsLinter;
//# sourceMappingURL=tsLinter.js.map